@@ -18,7 +18,15 @@ from urllib3.util.ssl_ import ssl_wrap_socket as urllib3_ssl_wrap_socket
 from urllib3.util.ssl_ import wrap_socket as urllib3_wrap_socket
 
 from .compat import basestring, byte_type, decode_from_bytes, encode_to_bytes, text_type
-from .utils import SSL_PROTOCOL, MocketSocketCore, get_mocketize, hexdump, hexload
+from .exceptions import StrictMocketException
+from .utils import (
+    SSL_PROTOCOL,
+    MocketMode,
+    MocketSocketCore,
+    get_mocketize,
+    hexdump,
+    hexload,
+)
 
 xxh32 = None
 try:
@@ -158,10 +166,7 @@ class MocketSocket:
         self._truesocket_recording_dir = None
         self.kwargs = kwargs
 
-    def __unicode__(self):  # pragma: no cover
-        return str(self)
-
-    def __str__(self):  # pragma: no cover
+    def __str__(self):
         return "({})(family={} type={} protocol={})".format(
             self.__class__.__name__, self.family, self.type, self.proto
         )
@@ -289,6 +294,9 @@ class MocketSocket:
         raise exc
 
     def true_sendall(self, data, *args, **kwargs):
+        if MocketMode().STRICT:
+            raise StrictMocketException("Mocket tried to use the real `socket` module.")
+
         req = decode_from_bytes(data)
         # make request unique again
         req_signature = _hash_request(hasher, req)
@@ -296,7 +304,7 @@ class MocketSocket:
         port = text_type(self._port)
 
         # prepare responses dictionary
-        responses = dict()
+        responses = {}
 
         if Mocket.get_truesocket_recording_dir():
             path = os.path.join(
@@ -322,9 +330,9 @@ class MocketSocket:
                     raise
         except KeyError:
             # preventing next KeyError exceptions
-            responses.setdefault(self._host, dict())
-            responses[self._host].setdefault(port, dict())
-            responses[self._host][port].setdefault(req_signature, dict())
+            responses.setdefault(self._host, {})
+            responses[self._host].setdefault(port, {})
+            responses[self._host][port].setdefault(req_signature, {})
             response_dict = responses[self._host][port][req_signature]
 
         # try to get the response from the dictionary
@@ -425,7 +433,7 @@ class Mocket:
 
     @classmethod
     def collect(cls, data):
-        cls._requests.append(data)
+        cls.request_list().append(data)
 
     @classmethod
     def reset(cls):
@@ -436,17 +444,21 @@ class Mocket:
 
     @classmethod
     def last_request(cls):
-        if cls._requests:
-            return cls._requests[-1]
+        if cls.has_requests():
+            return cls.request_list()[-1]
+
+    @classmethod
+    def request_list(cls):
+        return cls._requests
 
     @classmethod
     def remove_last_request(cls):
-        if cls._requests:
+        if cls.has_requests():
             del cls._requests[-1]
 
     @classmethod
     def has_requests(cls):
-        return len(cls._requests) > 0
+        return bool(cls.request_list())
 
     @staticmethod
     def enable(namespace=None, truesocket_recording_dir=None):
@@ -596,10 +608,17 @@ class MocketEntry:
 
 
 class Mocketizer:
-    def __init__(self, instance=None, namespace=None, truesocket_recording_dir=None):
+    def __init__(
+        self,
+        instance=None,
+        namespace=None,
+        truesocket_recording_dir=None,
+        strict_mode=False,
+    ):
         self.instance = instance
         self.truesocket_recording_dir = truesocket_recording_dir
         self.namespace = namespace or text_type(id(self))
+        MocketMode().STRICT = strict_mode
 
     def enter(self):
         Mocket.enable(
@@ -628,28 +647,34 @@ class Mocketizer:
     async def __aexit__(self, *args, **kwargs):
         self.exit()
 
-    def check_and_call(self, method):
-        method = getattr(self.instance, method, None)
+    def check_and_call(self, method_name):
+        method = getattr(self.instance, method_name, None)
         if callable(method):
             method()
 
-
-def wrapper(test, cls=Mocketizer, truesocket_recording_dir=None, *args, **kwargs):
-    instance = args[0] if args else None
-    namespace = None
-    if truesocket_recording_dir:
-        namespace = ".".join(
-            (
-                instance.__class__.__module__,
-                instance.__class__.__name__,
-                test.__name__,
+    @staticmethod
+    def factory(test, truesocket_recording_dir, strict_mode, args):
+        instance = args[0] if args else None
+        namespace = None
+        if truesocket_recording_dir:
+            namespace = ".".join(
+                (
+                    instance.__class__.__module__,
+                    instance.__class__.__name__,
+                    test.__name__,
+                )
             )
+
+        return Mocketizer(
+            instance,
+            namespace=namespace,
+            truesocket_recording_dir=truesocket_recording_dir,
+            strict_mode=strict_mode,
         )
-    with cls(
-        instance,
-        namespace=namespace,
-        truesocket_recording_dir=truesocket_recording_dir,
-    ):
+
+
+def wrapper(test, truesocket_recording_dir=None, strict_mode=False, *args, **kwargs):
+    with Mocketizer.factory(test, truesocket_recording_dir, strict_mode, args):
         return test(*args, **kwargs)
 
 
